use super::render_error;
use crate::{assets::initial_context, get_lang, get_user_from_token, State};
use axum::{
    response::{Html, IntoResponse},
    Extension,
};
use axum_extra::extract::CookieJar;
use tetratto_core::model::Error;

/// `/developer`
pub async fn home_request(jar: CookieJar, Extension(data): Extension<State>) -> impl IntoResponse {
    let data = data.read().await;
    let user = match get_user_from_token!(jar, data.0) {
        Some(ua) => ua,
        None => {
            return Err(Html(
                render_error(Error::NotAllowed, &jar, &data, &None).await,
            ));
        }
    };

    let list = match data.0.get_apps_by_owner(user.id).await {
        Ok(p) => p,
        Err(e) => return Err(Html(render_error(e, &jar, &data, &Some(user)).await)),
    };

    let lang = get_lang!(jar, data.0);
    let mut context = initial_context(&data.0.0.0, lang, &Some(user)).await;
    context.insert("list", &list);

    // return
    Ok(Html(
        data.1.render("developer/home.html", &context).unwrap(),
    ))
}
